.. Use python as the default language for syntax highlighting in this file
.. highlight:: python

.. default-domain:: py

boutdata package
================

Module contents
---------------

.. automodule:: boutdata
    :members:
    :undoc-members:

Submodules
----------

boutdata.cbdtoeqdsk module
--------------------------

.. automodule:: boutdata.cbdtoeqdsk
    :members:
    :undoc-members:

boutdata.collect module
-----------------------

.. automodule:: boutdata.collect
    :members:
    :undoc-members:

boutdata.data module
--------------------

.. automodule:: boutdata.data
    :members:
    :undoc-members:

boutdata.gen\_surface module
----------------------------

.. automodule:: boutdata.gen_surface
    :members:
    :undoc-members:

boutdata.griddata module
------------------------

.. automodule:: boutdata.griddata
    :members:
    :undoc-members:

boutdata.input module
---------------------

.. automodule:: boutdata.input
    :members:
    :undoc-members:

boutdata.mayavi2 module
-----------------------

.. automodule:: boutdata.mayavi2
    :members:
    :undoc-members:

boutdata.mms module
-------------------

.. automodule:: boutdata.mms
    :members:
    :undoc-members:

boutdata.pol\_slice module
--------------------------

.. automodule:: boutdata.pol_slice
    :members:
    :undoc-members:

boutdata.processor\_rearrange module
------------------------------------

.. automodule:: boutdata.processor_rearrange
    :members:
    :undoc-members:

boutdata.restart module
-----------------------

.. automodule:: boutdata.restart
    :members:
    :undoc-members:

boutdata.settings module
------------------------

.. automodule:: boutdata.settings
    :members:
    :undoc-members:

boutdata.shiftz module
----------------------

.. automodule:: boutdata.shiftz
    :members:
    :undoc-members:

